@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/compose.php,v 2.800.2.117 2008/09/24 16:55:27 jan Exp $
+ * $Horde: imp/compose.php,v 2.800.2.119 2008/12/01 21:34:18 jan Exp $
  *
  * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
  *
@@ -71,10 +71,6 @@ $msg = '';
 
 /* The headers of the message. */
 $header = array(
-    'to' => '',
-    'cc' => '',
-    'bcc' => '',
-    'subject' => '',
     'in_reply_to' => Util::getFormData('in_reply_to'),
     'references' => Util::getFormData('references')
 );
@@ -680,7 +676,7 @@ if (!$reloaded && ($actionID != 'draft')) {
 }
 
 foreach (array('to', 'cc', 'bcc', 'subject') as $val) {
-    if (empty($header[$val])) {
+    if (!isset($header[$val])) {
         $header[$val] = Util::getFormData($val, $imp_ui->getAddressList(Util::getFormData($val), Util::getFormData($val . '_list'), Util::getFormData($val . '_field'), Util::getFormData($val . '_new')));
     }
 }
