@@ -3,17 +3,15 @@
  * The IMP_Fetchmail:: class provides an interface to download mail from
  * remote mail servers.
  *
- * $Horde: imp/lib/Fetchmail.php,v 1.41.8.5 2005/07/03 03:42:42 selsky Exp $
+ * $Horde: imp/lib/Fetchmail.php,v 1.41.8.14 2008/01/02 11:31:16 jan Exp $
  *
- * Copyright 2002-2005 Nuno Loureiro <nuno@co.sapo.pt>
- * Copyright 2004-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Nuno Loureiro <nuno@co.sapo.pt>
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 4.0
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package IMP
  */
 class IMP_Fetchmail {
@@ -71,10 +69,12 @@ class IMP_Fetchmail {
         require_once dirname(__FILE__) . '/Fetchmail/' . $driver . '.php';
         $class = 'IMP_Fetchmail_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $fetchmail = new $class($params);
         } else {
-            return false;
+            $fetchmail = false;
         }
+
+        return $fetchmail;
     }
 
     /**
@@ -90,25 +90,25 @@ class IMP_Fetchmail {
         $drivers = array();
 
         if (($dir = opendir(dirname(__FILE__) . '/Fetchmail'))) {
-            while (false !== ($file = readdir($dir))) { 
+            while (false !== ($file = readdir($dir))) {
                 if (!is_dir($file)) {
                     $driver = basename($file, '.php');
                     $class = 'IMP_Fetchmail_' . $driver;
                     require_once dirname(__FILE__) . '/Fetchmail/' . $file;
-                    if (($descrip = call_user_func(array($class, 'description')))) {
+                    if (is_callable(array($class, 'description')) &&
+                        ($descrip = call_user_func(array($class, 'description')))) {
                         $drivers[$driver] = $descrip;
                     }
                 }
-            } 
-
-            closedir($dir); 
+            }
+            closedir($dir);
         }
 
         return $drivers;
     }
 
     /**
-     * List the colors available for coloring fetched messages. 
+     * List the colors available for coloring fetched messages.
      * This function can be called statically:
      *   $list = IMP_Fetchmail::listColors();
      *
@@ -121,7 +121,7 @@ class IMP_Fetchmail {
             'aqua'
         );
     }
- 
+
     /**
      * Returns a description of the driver.
      * This function can be called statically:
@@ -212,17 +212,10 @@ class IMP_Fetchmail {
         /* If there is a user defined function, call it with the current
          * message as an argument. */
         if ($GLOBALS['conf']['hooks']['fetchmail_filter']) {
-            include_once HORDE_BASE . '/config/hooks.php';
-            if (function_exists('_imp_hook_fetchmail_filter')) {
-                $msg = call_user_func('_imp_hook_fetchmail_filter', $msg);
-            }
+            $msg = Horde::callHook('_imp_hook_fetchmail_filter', array($msg), 'imp');
         }
 
-        /* Make absolutely sure there are no bare newlines. */
-        $msg = preg_replace("|([^\r])\n|", "\\1\r\n", $msg);
-        $msg = str_replace("\n\n", "\n\r\n", $msg);
-
-        return $msg;
+        return IMP::removeBareNewlines($msg);
     }
 
     /**
@@ -260,8 +253,8 @@ class IMP_Fetchmail {
      */
     function _addMessage($msg)
     {
-        $newmailbox = IMP::serverString($this->_params['lmailbox']);
-        return @imap_append($GLOBALS['imp']['stream'], $newmailbox, $msg);
+        $imp_imap = &IMP_IMAP::singleton();
+        return @imap_append($imp_imap->stream(), IMP::serverString($this->_params['lmailbox']), $msg);
     }
 
     /**
@@ -270,15 +263,18 @@ class IMP_Fetchmail {
      * This function can be called statically.
      *
      * @param array $accounts  The list of account identifiers to fetch mail
-     *                         for. 
+     *                         for.
      */
     function fetchMail($accounts)
     {
-        $fm_account = &new IMP_Fetchmail_Account();
+        $fm_account = new IMP_Fetchmail_Account();
 
         foreach ($accounts as $val) {
             $params = $fm_account->getAllValues($val);
             $driver = &IMP_Fetchmail::factory($params['driver'], $params);
+            if ($driver === false) {
+                continue;
+            }
             $res = $driver->getMail();
 
             if (is_a($res, 'PEAR_Error')) {
@@ -295,13 +291,11 @@ class IMP_Fetchmail {
 
 }
 
-
 /**
  * The IMP_Fetchmail_Account:: class provides an interface to accessing
  * fetchmail preferences for all mail accounts a user might have.
  *
  * @author  Nuno Loureiro <nuno@co.sapo.pt>
- * @since   IMP 4.0
  * @package IMP
  */
 class IMP_Fetchmail_Account {
@@ -326,6 +320,16 @@ class IMP_Fetchmail_Account {
         }
     }
 
+    /**
+     * Return the number of accounts.
+     *
+     * @return integer  Number of active accounts.
+     */
+    function count()
+    {
+        return count($this->_accounts);
+    }
+
     /**
      * Saves all accounts in the prefs backend.
      *
