@@ -128,7 +128,7 @@ define('IMP_IDX_SEP', "\1");
 /**
  * IMP Base Class.
  *
- * $Horde: imp/lib/IMP.php,v 1.449.4.120 2008/09/18 10:25:00 jan Exp $
+ * $Horde: imp/lib/IMP.php,v 1.449.4.122 2008/12/01 21:10:27 jan Exp $
  *
  * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
  *
@@ -331,11 +331,11 @@ class IMP {
     function checkRequestToken($slug, $token)
     {
         if (empty($_SESSION['horde_form_secrets'][$token])) {
-            return PEAR::raiseError(_("We cannot verify that this request was really sent by you. It could be a malicious request."));
+            return PEAR::raiseError(_("We cannot verify that this request was really sent by you. It could be a malicious request. If you intended to perform this action, you can retry it now."));
         }
 
         if ($_SESSION['horde_form_secrets'][$token] + $GLOBALS['conf']['server']['token_lifetime'] < time()) {
-            return PEAR::raiseError(sprintf(_("This request cannot be completed because the link you followed or the form you submitted was only valid for %d minutes"), round($GLOBALS['conf']['server']['token_lifetime'] / 60)));
+            return PEAR::raiseError(sprintf(_("This request cannot be completed because the link you followed or the form you submitted was only valid for %d minutes. Please try again now."), round($GLOBALS['conf']['server']['token_lifetime'] / 60)));
         }
 
         return true;
@@ -578,7 +578,7 @@ class IMP {
         if (isset($args['to']) && (strpos($args['to'], 'mailto:') === 0)) {
             $mailto = @parse_url($args['to']);
             if (is_array($mailto)) {
-                $args['to'] = $mailto['path'];
+                $args['to'] = isset($mailto['path']) ? $mailto['path'] : '';
                 if (!empty($mailto['query'])) {
                     parse_str($mailto['query'], $vals);
                     foreach ($fields as $val) {
