@@ -4,7 +4,7 @@
  * and provides an option to import the data into a calendar source,
  * if one is available.
  *
- * $Horde: imp/lib/MIME/Viewer/itip.php,v 1.37.2.41 2008/08/25 12:01:58 jan Exp $
+ * $Horde: imp/lib/MIME/Viewer/itip.php,v 1.37.2.42 2008/10/07 12:36:07 jan Exp $
  *
  * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
@@ -332,7 +332,9 @@ class IMP_MIME_Viewer_itip extends MIME_Viewer {
                     $msg_headers->addMIMEHeaders($mime);
 
                     // Send the reply.
-                    $status = $mime->send($organizerEmail, $msg_headers);
+                    $status = $mime->send($organizerEmail, $msg_headers,
+                                          $GLOBALS['conf']['mailer']['type'],
+                                          $GLOBALS['conf']['mailer']['params']);
                     if (is_a($status, 'PEAR_Error')) {
                         $this->_msgs[$key][] = array('error', sprintf(_("Error sending reply: %s."), $status->getMessage()));
                     } else {
@@ -435,7 +437,9 @@ class IMP_MIME_Viewer_itip extends MIME_Viewer {
                     $msg_headers->addMIMEHeaders($mime);
 
                     // Send the reply.
-                    $status = $mime->send($organizerEmail, $msg_headers);
+                    $status = $mime->send($organizerEmail, $msg_headers,
+                                          $GLOBALS['conf']['mailer']['type'],
+                                          $GLOBALS['conf']['mailer']['params']);
                     if (is_a($status, 'PEAR_Error')) {
                         $this->_msgs[$key][] = array('error', sprintf(_("Error sending reply: %s."), $status->getMessage()));
                     } else {
