@@ -2,15 +2,14 @@
 /**
  * Maintenance module that deletes old sent-mail folders.
  *
- * $Horde: imp/lib/Maintenance/Task/delete_sentmail_monthly.php,v 1.18.10.7 2006/01/01 21:28:59 jan Exp $
+ * $Horde: imp/lib/Maintenance/Task/delete_sentmail_monthly.php,v 1.18.10.11 2008/10/11 05:48:20 slusarz Exp $
  *
- * Copyright 2001-2006 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @since   IMP 2.3.7
+ * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde_Maintenance
  */
 class Maintenance_Task_delete_sentmail_monthly extends Maintenance_Task {
@@ -22,7 +21,7 @@ class Maintenance_Task_delete_sentmail_monthly extends Maintenance_Task {
      */
     function doMaintenance()
     {
-        global $imp, $notification, $prefs;
+        global $notification, $prefs;
 
         /* Get list of all folders, parse through and get the list of all
            old sent-mail folders. Then sort this array according to
@@ -40,7 +39,7 @@ class Maintenance_Task_delete_sentmail_monthly extends Maintenance_Task {
         foreach (array_keys($old_folders) as $k) {
             foreach ($sent_mail_folders as $folder) {
                 if (preg_match('/^' . str_replace('/', '\/', $folder) . '-([^-]+)-([0-9]{4})$/i', $k, $regs)) {
-                    $folder_array[$k] = (is_numeric($regs[1])) ? mktime(0, 0, 0,$regs[1], 1, $regs[2]) : strtotime("$regs[1] 1, $regs[2]");
+                    $folder_array[$k] = String::convertCharset((is_numeric($regs[1])) ? mktime(0, 0, 0,$regs[1], 1, $regs[2]) : strtotime("$regs[1] 1, $regs[2]"), NLS::getCharset(), 'UTF7-IMAP');
                 }
             }
         }
@@ -52,7 +51,7 @@ class Maintenance_Task_delete_sentmail_monthly extends Maintenance_Task {
             $notification->push(_("Old sent-mail folders being purged."), 'horde.message');
 
             /* Delete the old folders now. */
-            if ($imp_folder->delete($purge_folders, $prefs->getValue('subscribe'))) {
+            if ($imp_folder->delete($purge_folders, true)) {
                 return true;
             }
         }
