@@ -11,7 +11,7 @@
  *     )
  * );
  *
- * mail_user_folder --  The path to folder mail mercury
+ * 'mail_user_folder' --  The path to folder mail mercury
  *
  *****************************************************************************
  * PROBLEM TO ACCESS NETWORK DIRECOTRY
@@ -30,29 +30,18 @@
  * UNC path ("\\\\shareDrive\\shareDir").
  *****************************************************************************
  *
- * $Horde: imp/lib/Quota/mercury32.php,v 1.1.10.8 2007/01/02 13:55:02 jan Exp $
+ * $Horde: imp/lib/Quota/mercury32.php,v 1.1.10.11 2008/07/02 09:31:14 jan Exp $
  *
- * Copyright 2002-2007 Frank Lupo <frank_lupo@email.it>
+ * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Frank Lupo <frank_lupo@email.it>
- * @since   IMP 4.0
  * @package IMP_Quota
  */
 class IMP_Quota_mercury32 extends IMP_Quota {
 
-    /**
-     * Constructor
-     *
-     * @param array $params  Hash containing connection parameters.
-     */
-    function IMP_Quota_mercury32($params = array())
-    {
-        $this->_params = $params;
-    }
-
     /**
      * Get quota information (used/allocated), in bytes.
      *
@@ -72,7 +61,7 @@ class IMP_Quota_mercury32 extends IMP_Quota {
             }
             closedir($dir);
 
-            if (!is_null($quota)) {
+            if ($quota !== null) {
                 return array('usage' => $quota, 'limit' => 0);
             }
         }
