@@ -40,7 +40,7 @@ define('IMP_SEARCH_SHOW_SUBSCRIBED_ONLY', 1);
  *     'vinbox_id' => string (The Virtual Inbox query ID)
  * );
  *
- * $Horde: imp/lib/Search.php,v 1.37.10.45 2008/08/22 16:35:44 jan Exp $
+ * $Horde: imp/lib/Search.php,v 1.37.10.46 2008/12/10 05:13:07 slusarz Exp $
  *
  * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
@@ -204,12 +204,15 @@ class IMP_Search {
     /**
      * Deletes an IMAP search query.
      *
-     * @param string $id  The search query id to use (by default, will use
-     *                    the current ID set in the object).
+     * @param string $id          The search query id to use (by default, will
+     *                            use the current ID set in the object).
+     * @param boolean $no_delete  Don't delete the entry in the tree object.
+     *
+     *
      *
      * @return string  Returns the search query id.
      */
-    function deleteSearchQuery($id = null)
+    function deleteSearchQuery($id = null, $no_delete = false)
     {
         $id = $this->_strip($id);
         $is_vfolder = !empty($_SESSION['imp']['search']['q'][$id]['vfolder']);
@@ -219,7 +222,9 @@ class IMP_Search {
             $vfolders = $this->_getVFolderList();
             unset($vfolders[$id]);
             $this->_saveVFolderList($vfolders);
-            $this->_updateIMPTree('delete', $id);
+            if (!$no_delete) {
+                $this->_updateIMPTree('delete', $id);
+            }
         }
     }
 
@@ -355,7 +360,7 @@ class IMP_Search {
         /* Delete the current Virtual Trash folder, if it exists. */
         $vtrash_id = $GLOBALS['prefs']->getValue('vtrash_id');
         if (!empty($vtrash_id)) {
-            $this->deleteSearchQuery($vtrash_id);
+            $this->deleteSearchQuery($vtrash_id, true);
         }
 
         if (!$GLOBALS['prefs']->getValue('use_vtrash')) {
@@ -418,7 +423,7 @@ class IMP_Search {
         /* Delete the current Virtual Inbox folder, if it exists. */
         $vinbox_id = $GLOBALS['prefs']->getValue('vinbox_id');
         if (!empty($vinbox_id)) {
-            $this->deleteSearchQuery($vinbox_id);
+            $this->deleteSearchQuery($vinbox_id, true);
         }
 
         if (!$GLOBALS['prefs']->getValue('use_vinbox')) {
